xlawrence 2005/05/09 14:51:37 CEST
Modified files:
src/java/org/jahia/suite/calendar/framework Transport.java
src/java/org/jahia/suite/calendar/framework/jms
JMSTransportReceiver.java
JMSTransportSender.java
Log:
Updated sources
Revision Changes Path
1.2 +4 -2
uwcal_JSR168/src/java/org/jahia/suite/calendar/framework/Transport.java
http://jahia.mine.nu:8080/cgi-bin/cvsweb.cgi/uwcal_JSR168/src/java/org/jahia/suite/calendar/framework/Transport.java.diff?r1=1.1&r2=1.2&f=h
1.6 +1 -1
uwcal_JSR168/src/java/org/jahia/suite/calendar/framework/jms/JMSTransportReceiver.java
http://jahia.mine.nu:8080/cgi-bin/cvsweb.cgi/uwcal_JSR168/src/java/org/jahia/suite/calendar/framework/jms/JMSTransportReceiver.java.diff?r1=1.5&r2=1.6&f=h
1.6 +1 -1
uwcal_JSR168/src/java/org/jahia/suite/calendar/framework/jms/JMSTransportSender.java
http://jahia.mine.nu:8080/cgi-bin/cvsweb.cgi/uwcal_JSR168/src/java/org/jahia/suite/calendar/framework/jms/JMSTransportSender.java.diff?r1=1.5&r2=1.6&f=h
Index: JMSTransportReceiver.java
===================================================================
RCS file:
/home/cvs/repository/uwcal_JSR168/src/java/org/jahia/suite/calendar/framework/jms/JMSTransportReceiver.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- JMSTransportReceiver.java 10 Feb 2005 09:06:22 -0000 1.5
+++ JMSTransportReceiver.java 9 May 2005 12:51:36 -0000 1.6
@@ -135,7 +135,7 @@
/**
* @see org.jahia.suite.calendar.framework.Transport
*/
- public void start() throws TransportException {
+ public void start(String host, int port) throws TransportException {
throw new TransportException("Not implemented");
}
Index: JMSTransportSender.java
===================================================================
RCS file:
/home/cvs/repository/uwcal_JSR168/src/java/org/jahia/suite/calendar/framework/jms/JMSTransportSender.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- JMSTransportSender.java 10 Feb 2005 09:06:22 -0000 1.5
+++ JMSTransportSender.java 9 May 2005 12:51:36 -0000 1.6
@@ -157,7 +157,7 @@
/**
* @see org.jahia.suite.calendar.framework.Transport
*/
- public void start() throws TransportException {
+ public void start(String host, int port) throws TransportException {
throw new TransportException("Not implemented");
}
Index: Transport.java
===================================================================
RCS file:
/home/cvs/repository/uwcal_JSR168/src/java/org/jahia/suite/calendar/framework/Transport.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- Transport.java 19 Nov 2004 15:02:46 -0000 1.1
+++ Transport.java 9 May 2005 12:51:36 -0000 1.2
@@ -51,9 +51,11 @@
/**
* This method should be called to initialize transport and communication
* ressources. It should be invoked prior to sending/receiving Message.
* @throws TransportException If ressource initialization fails.
*/
- public void start() throws TransportException;
+ public void start(String host, int port) throws TransportException;
/**
* This method frees the transport and communication ressources and
should
@@ -51,9 +51,11 @@
* This method should be called to initialize transport and communication
* ressources. It should be invoked prior to sending/receiving Message.
- * @throws TransportException If ressource initialization fails.
+ * @param host Hostname of the JMS server
+ * @param port Port dedicated to the JMS Server
+ * @throws TransportException If ressource initialization fails
*/